==> rice-impex-server-bootstrap-2.1.14-sql.jar: sql/oracle/KRIM_ATTR_DEFN_T.sql <==
TRUNCATE TABLE KRIM_ATTR_DEFN_T DROP STORAGE
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','1','beanName','KR-SYS','5ADF18B6D4887954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','10','editMode','KR-NS','5ADF18B6D4917954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','11','parameterName','KR-NS','5ADF18B6D4927954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','12','campusCode','KR-NS','5ADF18B6D4937954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','13','documentTypeName','KR-WKFLW','5ADF18B6D4947954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','14','actionRequestCd','KR-WKFLW','5ADF18B6D4957954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','15','routeStatusCode','KR-WKFLW','5ADF18B6D4967954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','16','routeNodeName','KR-WKFLW','5ADF18B6D4977954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','18','roleName','KR-IDM','5ADF18B6D4997954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','19','permissionName','KR-IDM','5ADF18B6D49A7954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','2','actionClass','KR-SYS','5ADF18B6D4897954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','20','responsibilityName','KR-IDM','5ADF18B6D49B7954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','21','groupName','KR-IDM','5ADF18B6D49C7954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','3','buttonName','KR-SYS','5ADF18B6D48A7954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','4','namespaceCode','KR-NS','5ADF18B6D48B7954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','40','required','KR-WKFLW','5C4970B2B2DF8277E0404F8189D80B30',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','41','actionDetailsAtRoleMemberLevel','KR-WKFLW','5C4970B2B2E08277E0404F8189D80B30',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','42','documentNumber','KR-NS','5C7D997640635002E0404F8189D86F11',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','44','sectionId','KR-NS','603B735FA6BCFE21E0404F8189D8083B',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','46','qualifierResolverProvidedIdentifier','KR-IDM','69FA55ACC2EE2598E0404F8189D86880',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','47','viewId','KR-KRAD','B7DBFABEFD308CBFE0402E0AA9D757C9',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','48','actionEvent','KR-KRAD','B7DBFABEFD318CBFE0402E0AA9D757C9',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','49','collectionPropertyName','KR-KRAD','B7DBFABEFD328CBFE0402E0AA9D757C9',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','5','componentName','KR-NS','5ADF18B6D48C7954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','50','fieldId','KR-KRAD','B7DBFABEFD338CBFE0402E0AA9D757C9',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','51','groupId','KR-KRAD','B7DBFABEFD348CBFE0402E0AA9D757C9',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','52','widgetId','KR-KRAD','B7DBFABEFD358CBFE0402E0AA9D757C9',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','53','actionId','KR-KRAD','B7DBFABEFD368CBFE0402E0AA9D757C9',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','54','appDocStatus','KR-WKFLW','BC5444677C22328CE0402E0AA9D77D80',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','6','propertyName','KR-NS','5ADF18B6D48D7954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','7','existingRecordsOnly','KR-NS','603B735FA6BAFE21E0404F8189D8083B',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','8','createdBySelfOnly','KR-NS','5ADF18B6D48F7954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','9','attachmentTypeCode','KR-NS','5ADF18B6D4907954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,LBL,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','KR1000','Application Code','appCode','KR-SYS','CEA27C3715268653E040F90A05B924A3',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,LBL,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','KR1001','Kim Type Name','kimTypeName','KR-IDM','CEA27C3715298653E040F90A05B924A3',1)
/

==> rice-impex-server-bootstrap-2.3.12-sql.jar: sql/oracle/KRIM_ATTR_DEFN_T.sql <==
TRUNCATE TABLE KRIM_ATTR_DEFN_T DROP STORAGE
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','1','beanName','KR-SYS','5ADF18B6D4887954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','10','editMode','KR-NS','5ADF18B6D4917954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','11','parameterName','KR-NS','5ADF18B6D4927954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','12','campusCode','KR-NS','5ADF18B6D4937954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','13','documentTypeName','KR-WKFLW','5ADF18B6D4947954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','14','actionRequestCd','KR-WKFLW','5ADF18B6D4957954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','15','routeStatusCode','KR-WKFLW','5ADF18B6D4967954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','16','routeNodeName','KR-WKFLW','5ADF18B6D4977954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','18','roleName','KR-IDM','5ADF18B6D4997954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','19','permissionName','KR-IDM','5ADF18B6D49A7954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','2','actionClass','KR-SYS','5ADF18B6D4897954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','20','responsibilityName','KR-IDM','5ADF18B6D49B7954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','21','groupName','KR-IDM','5ADF18B6D49C7954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','3','buttonName','KR-SYS','5ADF18B6D48A7954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','4','namespaceCode','KR-NS','5ADF18B6D48B7954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','40','required','KR-WKFLW','5C4970B2B2DF8277E0404F8189D80B30',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','41','actionDetailsAtRoleMemberLevel','KR-WKFLW','5C4970B2B2E08277E0404F8189D80B30',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','42','documentNumber','KR-NS','5C7D997640635002E0404F8189D86F11',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','44','sectionId','KR-NS','603B735FA6BCFE21E0404F8189D8083B',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','46','qualifierResolverProvidedIdentifier','KR-IDM','69FA55ACC2EE2598E0404F8189D86880',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','47','viewId','KR-KRAD','B7DBFABEFD308CBFE0402E0AA9D757C9',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','48','actionEvent','KR-KRAD','B7DBFABEFD318CBFE0402E0AA9D757C9',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','49','collectionPropertyName','KR-KRAD','B7DBFABEFD328CBFE0402E0AA9D757C9',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','5','componentName','KR-NS','5ADF18B6D48C7954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','50','fieldId','KR-KRAD','B7DBFABEFD338CBFE0402E0AA9D757C9',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','51','groupId','KR-KRAD','B7DBFABEFD348CBFE0402E0AA9D757C9',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','52','widgetId','KR-KRAD','B7DBFABEFD358CBFE0402E0AA9D757C9',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','53','actionId','KR-KRAD','B7DBFABEFD368CBFE0402E0AA9D757C9',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','54','appDocStatus','KR-WKFLW','BC5444677C22328CE0402E0AA9D77D80',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','6','propertyName','KR-NS','5ADF18B6D48D7954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','7','existingRecordsOnly','KR-NS','603B735FA6BAFE21E0404F8189D8083B',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','8','createdBySelfOnly','KR-NS','5ADF18B6D48F7954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','9','attachmentTypeCode','KR-NS','5ADF18B6D4907954E0404F8189D85002',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,LBL,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','KR1000','Application Code','appCode','KR-SYS','CEA27F2DB2DA3593E040F90A05B924DB',1)
/
INSERT INTO KRIM_ATTR_DEFN_T (ACTV_IND,CMPNT_NM,KIM_ATTR_DEFN_ID,LBL,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','org.kuali.rice.kim.bo.impl.KimAttributes','KR1001','Kim Type Name','kimTypeName','KR-IDM','CEA27F2DB2DD3593E040F90A05B924DB',1)
/
